==> kaffe-0.6.0.tgz: kaffe-0.6.0/kaffevm/jit/codeproto.h <==
/* codeproto.h
 * Code prototypes.
 *
 * Copyright (c) 1996 T. J. Wilkinson & Associates, London, UK.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * Written by Tim Wilkinson <tim@tjwassoc.demon.co.uk>
 */

#ifndef __codeproto_h
#define __codeproto_h

void _start_basic_block(uintp, uintp);
void _end_basic_block(uintp, uintp);

void move_long_const(SlotInfo*, jlong);
void move_double_const(SlotInfo*, jdouble);

void add_int(SlotInfo*, SlotInfo*, SlotInfo*);
void sub_int(SlotInfo*, SlotInfo*, SlotInfo*);
void mul_int(SlotInfo*, SlotInfo*, SlotInfo*);
void div_int(SlotInfo*, SlotInfo*, SlotInfo*);
void rem_int(SlotInfo*, SlotInfo*, SlotInfo*);
void and_int(SlotInfo*, SlotInfo*, SlotInfo*);
void or_int(SlotInfo*, SlotInfo*, SlotInfo*);
void xor_int(SlotInfo*, SlotInfo*, SlotInfo*);

void ashr_int(SlotInfo*, SlotInfo*, SlotInfo*);
void lshr_int(SlotInfo*, SlotInfo*, SlotInfo*);
void lshl_int(SlotInfo*, SlotInfo*, SlotInfo*);

void cmp_int(SlotInfo*, SlotInfo*, SlotInfo*);
void cmp_int_const(SlotInfo*, SlotInfo*, jint);

void pusharg_int(SlotInfo*);
void pusharg_int_const(jint);
void pusharg_long(SlotInfo*);
void pusharg_float(SlotInfo*);
void pusharg_double(SlotInfo*);
void popargs(int);

void return_int(SlotInfo*);
void return_long(SlotInfo*);
void return_float(SlotInfo*);
void return_double(SlotInfo*);

void call_ref(uintp);
void softcall_badarrayindex(void);
void softcall_nullpointer(void);

label* build_code_ref(uint8*, uintp);

void load_offset_int(SlotInfo*, SlotInfo*, jint);
void store_offset_int(SlotInfo*, jint, SlotInfo*);

#endif

==> kaffe-0.7.0.tgz: kaffe-0.7.0/kaffevm/jit/codeproto.h <==
/* codeproto.h
 * Code prototypes.
 *
 * Copyright (c) 1996 T. J. Wilkinson & Associates, London, UK.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * Written by Tim Wilkinson <tim@tjwassoc.demon.co.uk>
 */

#ifndef __codeproto_h
#define __codeproto_h

void _start_basic_block(uintp, uintp);
void _end_basic_block(uintp, uintp);
void _fixup_function_call(uintp, uintp);
void _prepare_function_call(uintp, uintp);

void move_long_const(SlotInfo*, jlong);
void move_double_const(SlotInfo*, jdouble);
void move_label_const(SlotInfo*, label*);

void add_int(SlotInfo*, SlotInfo*, SlotInfo*);
void sub_int(SlotInfo*, SlotInfo*, SlotInfo*);
void mul_int(SlotInfo*, SlotInfo*, SlotInfo*);
void div_int(SlotInfo*, SlotInfo*, SlotInfo*);
void rem_int(SlotInfo*, SlotInfo*, SlotInfo*);
void and_int(SlotInfo*, SlotInfo*, SlotInfo*);
void or_int(SlotInfo*, SlotInfo*, SlotInfo*);
void xor_int(SlotInfo*, SlotInfo*, SlotInfo*);

void ashr_int(SlotInfo*, SlotInfo*, SlotInfo*);
void lshr_int(SlotInfo*, SlotInfo*, SlotInfo*);
void lshl_int(SlotInfo*, SlotInfo*, SlotInfo*);

void cmp_int(SlotInfo*, SlotInfo*, SlotInfo*);
void cmp_int_const(SlotInfo*, SlotInfo*, jint);

void pusharg_int(SlotInfo*, int);
void pusharg_int_const(jint, int);
void pusharg_long(SlotInfo*, int);
void pusharg_float(SlotInfo*, int);
void pusharg_double(SlotInfo*, int);
void popargs(void);

void return_int(SlotInfo*);
void return_long(SlotInfo*);
void return_float(SlotInfo*);
void return_double(SlotInfo*);

void call_ref(uintp);
void softcall_badarrayindex(void);
void softcall_nullpointer(void);

label* build_code_ref(uint8*, uintp);
label* reference_code_label(int32);
label* reference_table_label(int32);

void load_float(SlotInfo*, SlotInfo*);
void load_double(SlotInfo*, SlotInfo*);

void load_offset_int(SlotInfo*, SlotInfo*, jint);
void store_offset_int(SlotInfo*, jint, SlotInfo*);

void addCodeConstant(label*);
void establishCodeConstants(void);

#endif
